# vibrio
[![.NET](https://github.com/notjagan/vibrio/actions/workflows/dotnet.yml/badge.svg)](https://github.com/notjagan/vibrio/actions/workflows/dotnet.yml)
[![CodeFactor](https://www.codefactor.io/repository/github/notjagan/vibrio/badge)](https://www.codefactor.io/repository/github/notjagan/vibrio)

utility to expose an api to internal osu!lazer functionality, including pp calculation
